@@ -20,23 +20,22 @@
 ####################################################################################
 
 tar -xzvf rosetta-serverguide.tar.gz
-rm -rf rosetta-serverguide/serverguide.pot
-for x in rosetta-serverguide/*; do
+rm rosetta-serverguide/serverguide.pot
+mv rosetta-serverguide po
+rm rosetta-serverguide.tar.gz
+
+for x in po/*; do
 	y=$(basename ${x} .po)
 	echo ${y}
 	mkdir -p ${y}
-	xml2po -e -p ${x} C/bookinfo.xml >${y}/bookinfo.xml
-	xml2po -e -p ${x} C/installation.xml >${y}/installation.xml
-	xml2po -e -p ${x} C/introduction.xml >${y}/introduction.xml
-	xml2po -e -p ${x} C/network-applications.xml >${y}/network-applications.xml
-	xml2po -e -p ${x} C/packaging.xml >${y}/packaging.xml
-	xml2po -e -p ${x} C/serverguide.xml >${y}/serverguide.xml
-	xml2po -e -p ${x} C/serverguide-C.omf >${y}/serverguide-${y}.omf
-	xml2po -e -p ${x} C/windows-networking.xml >${y}/windows-networking.xml
+	for i in C/*xml; do
+		j=$(basename ${i} C/)
+		echo ${j}
+		xml2po -k -p ${x} C/${j} | replace-doctype-with.py C/${j} >${y}/${j}
+	done
+	xml2po -k -p ${x} C/serverguide-C.omf >${y}/serverguide-${y}.omf
 	sed -i -e s@\"C\"@\"${y}\"@g -e s@C/@${y}/@g ${y}/serverguide-${y}.omf
-	sed -i -e "s@/C/preface@/$y/preface@g" $y/serverguide.xml
-	../../validate.sh $y/serverguide.xml
+	../../validate.sh ${y}/serverguide.xml
 done
 
-rm -rf rosetta-serverguide*
 rm .xml2po.mo
